from nr_vocabularies.resources.config import NRVocabulariesResourceConfig
from nr_vocabularies.resources.resource import NRVocabulariesResource
from nr_vocabularies.services.config import NRVocabulariesServiceConfig
from nr_vocabularies.services.service import NRVocabulariesService

NR_VOCABULARIES_RESOURCE_CONFIG = NRVocabulariesResourceConfig
NR_VOCABULARIES_RESOURCE_CLASS = NRVocabulariesResource
NR_VOCABULARIES_SERVICE_CONFIG = NRVocabulariesServiceConfig
NR_VOCABULARIES_SERVICE_CLASS = NRVocabulariesService
